'use client'

import Image from 'next/image'
import Link from 'next/link'
import { usePathname, useRouter } from 'next/navigation'
import { useEffect } from 'react'

import { useQuery } from '@tanstack/react-query'

import useGetShippingData from '@/hooks/server/useGetShippingData'
import { cn, convertToMoney } from '@/lib/utils'
import deliveryIcon from '@/public/icons/delivery.png'
import hayPostLogo from '@/public/icons/hay-post.png'
import { getCart } from '@/server/getCart'
import { useCheckoutStore } from '@/store/checkout'

const Delivery = () => {
  const pathname = usePathname()
  const { shippingData } = useGetShippingData()
  const navigatedFromCheckout = useCheckoutStore(
    (state) => state.navigatedFromCheckout
  )
  const router = useRouter()
  const { data: cartData, isFetching } = useQuery({
    queryKey: ['cart'],
    queryFn: getCart,
  })

  useEffect(() => {
    if (
      !isFetching &&
      cartData?.products.length === 0 &&
      navigatedFromCheckout === '0'
    ) {
      router.push('/')
    }
  }, [isFetching])

  if (!shippingData) return null

  return (
    <div className='flex gap-4 sm:flex-col'>
      <Link
        href='/checkout'
        className={cn(
          'flex flex-1 flex-col items-center justify-center rounded-lg border p-4 pt-3 ring-primary transition-shadow hover:ring-2',
          pathname === '/checkout' && 'ring-2'
        )}
      >
        <Image src={deliveryIcon} alt='fast delivery' width={80} />
        <div className='-mt-2'>
          Արագ առաքում — {convertToMoney(shippingData[0].rate)}
        </div>
      </Link>
      <Link
        href='/checkout-haypost'
        className={cn(
          'flex flex-1 flex-col items-center justify-center rounded-lg border p-4 pt-3 ring-primary transition-shadow hover:ring-2',
          pathname === '/checkout-haypost' && 'ring-2'
        )}
      >
        <Image src={hayPostLogo} alt='fast delivery' width={180} />
        <div className='-mt-4'>
          Հայփոստով առաքում —{' '}
          {shippingData[1].rate ? shippingData[1].rate : 'Անվճար'}
        </div>
      </Link>
    </div>
  )
}

export default Delivery
