// import ProductCard from '@/components/cards/ProductCard'
import { buttonVariants } from '@/components/ui/button'
import axiosServer from '@/services/axiosServer'
import { ProductType } from '@/types'
import {
  HydrationBoundary,
  QueryClient,
  dehydrate,
} from '@tanstack/react-query'
import Link from 'next/link'
import Favorites from './Favorites'
import RemoveAll from './RemoveAll'

// export const dynamic = 'force-dynamic'

export default async function page() {
  // const favorites = await getFavorites()
  // console.log('🚀 ~ favorites:', favorites)
  const queryClient = new QueryClient()
  await queryClient.prefetchQuery({
    queryKey: ['favorites'],
    queryFn: async (): Promise<ProductType[] | undefined> => {
      const res = await axiosServer('api/favorites')
      return res.data.data
    },
  })

  return (
    <HydrationBoundary state={dehydrate(queryClient)}>
      <div className='flex-1'>
        <h1 className='pb-6 text-2xl font-bold'>Նախընտրածներ</h1>
        <Favorites />
        <div className='flex justify-end gap-4 px-4 py-8 sm:flex-col'>
          <RemoveAll />
          <Link
            href='/store'
            className={buttonVariants({ variant: 'outline' })}
          >
            Շարունակել գնումները
          </Link>
        </div>
      </div>
    </HydrationBoundary>
  )
}
