import type { Metadata } from 'next'
import Image from 'next/image'
import Link from 'next/link'
import { Suspense } from 'react'

import { buttonVariants } from '@/components/ui/button'
import { cn, sliceAndGetSlug } from '@/lib/utils'
import { getBlog } from '@/server/getBlog'

import RecentArticles from './RecentArticles'

export const dynamic = 'force-dynamic'

export async function generateMetadata(): Promise<Metadata> {
  return {
    title: 'Բլոգ | Նորություններ | Օգտակար խորհուրդներ | SiaMoods',
    description:
      'Բլոգ ★ զարդերի, նորաձևության նորությունների և տռենդների մասին ★ օգտակար խորհուրդներ, հետաքրքիր պատմություններ ★ Սեղմիր և իմացիր ավելին',
    publisher: 'SiaMoods',
    category: 'website',
    openGraph: {
      images: '/images/logo.png',
      title: 'Բլոգ | Նորություններ | Օգտակար խորհուրդներ | SiaMoods',
      description:
        'Բլոգ ★ զարդերի, նորաձևության նորությունների և տռենդների մասին ★ օգտակար խորհուրդներ, հետաքրքիր պատմություններ ★ Սեղմիր և իմացիր ավելին',
      type: 'website',
      siteName: 'SiaMoods',
      url: `${process.env.NEXT_PUBLIC_APP_URL}blog`,
    },
    alternates: {
      canonical: `${process.env.NEXT_PUBLIC_APP_URL}blog`,
    },
  }
}

export default async function page() {
  const blogData = await getBlog()

  return (
    <div className='container flex gap-12 pb-8 lg:flex-col-reverse'>
      <Suspense fallback={<div>Loading...</div>}>
        <RecentArticles />
      </Suspense>
      <div>
        <h1 className='text-2xl font-bold'>Բլոգ</h1>
        <div className='divide-y'>
          {blogData?.blog.map((item, index) => (
            <article
              key={index}
              className='flex flex-col items-start gap-2 py-10'
            >
              <h4 className='text-xl font-bold sm:text-lg'>{item.title}</h4>
              <div className='text-sm text-muted-foreground'>{item.date}</div>
              <Link
                href={`blog/${sliceAndGetSlug(item.slug)}`}
                className='w-full'
              >
                <Image
                  src={item.image}
                  alt={item.title}
                  width={900}
                  height={500}
                  className='my-4 aspect-[21/9] w-full rounded-md object-cover'
                />
              </Link>
              <Link
                href={`/blog/${item.slug}`}
                className={cn(buttonVariants())}
              >
                Կարդալ ավելին
              </Link>
            </article>
          ))}
        </div>
      </div>
    </div>
  )
}
