'use client'

import Subscribe from '@/components/Subscribe'
import { buttonVariants } from '@/components/ui/button'
import { cn } from '@/lib/utils'
import { getHomeData } from '@/server/getHome'
import { useQuery } from '@tanstack/react-query'
import Image from 'next/image'
import Link from 'next/link'

export default function Footer() {
  const { data: homeData } = useQuery({
    queryKey: ['home'],
    queryFn: getHomeData,
    staleTime: 1000 * 60 * 60,
  })

  if (!homeData) return <div>Something went wrong</div>

  const customizations = homeData.customizations

  return (
    <footer className='tap-8 container mt-auto flex flex-col items-center pb-2 pt-8'>
      <div className='flex flex-col items-center gap-12'>
        <Subscribe />
        <div className='flex flex-col items-center gap-4'>
          <h4 className='text-sm text-muted-foreground'>
            Միացեք մեզ սոցիալական ցանցերում
          </h4>
          <div className='flex gap-2'>
            {customizations.social.map((item) => (
              <Link key={item.url} href={item.url} target='_blank'>
                <Image src={item.icon} alt='social' width={32} height={32} />
              </Link>
            ))}
            {/* <Link
              href='https://www.facebook.com/'
              target='_blank'
              className={cn(
                buttonVariants({
                  variant: 'ghost',
                  size: 'icon',
                  className:
                    'rounded-full text-[1.75rem] hover:bg-blue-600 hover:text-background',
                })
              )}
            >
              <FaFacebookF />
            </Link>
            <Link
              href='https://www.instagram.com/'
              target='_blank'
              className={cn(
                buttonVariants({
                  variant: 'ghost',
                  size: 'icon',
                  className:
                    'rounded-full from-blue-500 via-red-500 to-yellow-500 text-3xl hover:bg-gradient-to-br hover:text-background',
                })
              )}
            >
              <FaInstagram />
            </Link>
            <Link
              href='https://www.pinterest.com/'
              target='_blank'
              className={cn(
                buttonVariants({
                  variant: 'ghost',
                  size: 'icon',
                  className:
                    'rounded-full text-3xl hover:bg-rose-600 hover:text-background',
                })
              )}
            >
              <FaPinterestP />
            </Link> */}
          </div>
        </div>
      </div>

      <div className='mt-12 flex w-full flex-col items-center border-t border-primary pt-12'>
        <div className='flex flex-wrap sm:flex-col'>
          {customizations.footerData.map((item, index) => (
            <Link
              key={index}
              href={item.href}
              className={cn(
                buttonVariants({
                  variant: 'ghost',
                })
              )}
            >
              {item.name}
            </Link>
          ))}
        </div>
        <div className='pb-2 pt-8 text-xs'>
          {customizations.copyright.value}
        </div>
      </div>
    </footer>
  )
}
