'use client'

import { Suspense } from 'react'

import { useQuery } from '@tanstack/react-query'
import Cookies from 'js-cookie'

import BlogCarousel from '@/components/BlogCarousel'
import CardCarousel from '@/components/CardCarousel'
import Delivery from '@/components/Delivery'
import Hero from '@/components/Hero'
import { getHomeData } from '@/server/getHome'
import { getRecentlyViewed } from '@/server/getRecentlyViewed'

export default function Home() {
  const { data: homeData } = useQuery({
    queryKey: ['home'],
    queryFn: getHomeData,
    staleTime: 1000 * 60 * 60,
  })
  const recentlyViewedProductsIds: number[] = JSON.parse(
    Cookies.get('recentlyViewedProductsIds') || '[]'
  )
  const { data: recentlyViewed = [] } = useQuery({
    queryKey: ['recentlyViewedProductsIds'],
    queryFn: () => getRecentlyViewed(recentlyViewedProductsIds),
    staleTime: 1000 * 60 * 60,
    enabled: !!recentlyViewedProductsIds.length,
  })
  const sortedRecentlyViewed = recentlyViewed.sort(
    (a, b) =>
      recentlyViewedProductsIds.indexOf(a.haysell_id) -
      recentlyViewedProductsIds.indexOf(b.haysell_id)
  )

  if (!homeData) return null

  return (
    <div>
      <Hero banners={homeData.banners} />
      <CardCarousel title='ՍԻՐՎԱԾ ԶԱՐԴԵՐ' href='/' products={homeData.liked} />
      <CardCarousel
        title='ՆՈՐ ՏԵՍԱԿԱՆԻ'
        href='/store?sort_by=0'
        products={homeData.new}
      />
      <Suspense fallback={<div>Loading...</div>}>
        <Delivery items={homeData.customizations.paymentDelivery} />
      </Suspense>
      <CardCarousel
        title='ԶԵՂՉՎԱԾ ՏԵՍԱԿԱՆԻ'
        href='/store?discount=1'
        products={homeData.discount}
      />
      <CardCarousel
        title='ՎԵՐՋԵՐՍ ԴԻՏՎԱԾ'
        href='/'
        products={sortedRecentlyViewed}
        isAutoPlay={false}
      />
      <BlogCarousel title='ԲԼՈԳ' href='/' blog={homeData.blog} />
    </div>
  )
}
