'use client'

import { useState } from 'react'

import { useWindowWidth } from '@/hooks/useWindowWidth'
import { cn } from '@/lib/utils'

const Magnified = ({
  src,
  boxCenter,
  IMAGE_DIM,
  BOX_DIM,
  MAGNIFIED_DIM,
}: {
  src: string
  boxCenter: { x: number; y: number }
  IMAGE_DIM: { w: number; h: number }
  BOX_DIM: { w: number; h: number }
  MAGNIFIED_DIM: { w: number; h: number }
}) => {
  const BG_DIM = {
    w: IMAGE_DIM.w * (MAGNIFIED_DIM.w / BOX_DIM.w),
    h: IMAGE_DIM.h * (MAGNIFIED_DIM.h / BOX_DIM.h),
  }

  return (
    <div
      className={`absolute left-[105%] top-0 z-10 overflow-hidden rounded-lg shadow-xl`}
      style={{
        width: `${MAGNIFIED_DIM.w}px`,
        height: `${MAGNIFIED_DIM.h}px`,
      }}
    >
      <div
        style={{
          width: `${BG_DIM.w}px`,
          height: `${BG_DIM.h}px`,
          objectFit: 'cover',
          transform: `translate(${
            ((boxCenter.x - BOX_DIM.w / 2) / IMAGE_DIM.w) * -100
          }%,${((boxCenter.y - BOX_DIM.h / 2) / IMAGE_DIM.h) * -100}%)`,
          backgroundImage: `url(${src})`,
          backgroundSize: `${BG_DIM.w}px ${BG_DIM.h}px`,
          backgroundPosition: `0 0`,
          backgroundColor: 'hsl(var(--background))',
        }}
      />
    </div>
  )
}

const Magnifier = ({
  src,
  isInDialog,
}: {
  src: string
  isInDialog?: boolean
}) => {
  const width = useWindowWidth()
  const [coordinates, setCoordinates] = useState<{
    x: number
    y: number
  } | null>(null)

  const IMAGE_DIM = {
    w: isInDialog ? 250 : 500,
    h: isInDialog ? 250 : 500,
  }

  const BOX_DIM = {
    w: isInDialog ? 100 : 200,
    h: isInDialog ? 100 : 200,
  }

  const MAGNIFIED_DIM = {
    w: isInDialog ? 400 : 500,
    h: isInDialog ? 400 : 500,
  }

  const handleMouseMove = (e: React.MouseEvent<HTMLImageElement>) => {
    if (width < 1024) return
    const bounds = (e.target as HTMLImageElement).getBoundingClientRect()
    const left = e.clientX - bounds.left
    const top = e.clientY - bounds.top

    setCoordinates({
      x: Math.min(Math.max(left, BOX_DIM.w / 2), bounds.width - BOX_DIM.w / 2),
      y: Math.min(Math.max(top, BOX_DIM.h / 2), bounds.height - BOX_DIM.h / 2),
    })
  }

  const handleMouseLeave = () => {
    if (width < 1024) return
    setCoordinates(null)
  }

  return (
    <div className='relative'>
      <div
        onMouseMove={handleMouseMove}
        onMouseLeave={handleMouseLeave}
        className={cn(
          'rounded-lg border bg-cover bg-center sm:!h-[90vw] sm:!w-[90vw]',
          !isInDialog && 'sm:!h-[90vw] sm:!w-[90vw]'
        )}
        style={{
          width: `${IMAGE_DIM.w}px`,
          height: `${IMAGE_DIM.h}px`,
          backgroundImage: `url(${src})`,
        }}
      />
      {coordinates !== null && (
        <div
          className='pointer-events-none absolute rounded-md border border-input bg-background/30 object-cover'
          style={{
            width: `${BOX_DIM.w}px`,
            height: `${BOX_DIM.h}px`,
            top: `${coordinates.y - BOX_DIM.h / 2}px`,
            left: `${coordinates.x - BOX_DIM.w / 2}px`,
          }}
        />
      )}
      {coordinates !== null && (
        <Magnified
          src={src}
          boxCenter={coordinates}
          IMAGE_DIM={IMAGE_DIM}
          BOX_DIM={BOX_DIM}
          MAGNIFIED_DIM={MAGNIFIED_DIM}
        />
      )}
    </div>
  )
}

export default Magnifier
