import { ChevronLeft, ChevronRight } from 'lucide-react'

import { Button } from '@/components/ui/button'
import { cn } from '@/lib/utils'
import type { ImageType } from '@/types'

import ImageWithFallback from '../ImageWithFallback'

const ProductCardImages = ({
  images,
  selectedImage,
  setSelectedImage,
  isInProduct = false,
}: {
  images: ImageType[] | []
  selectedImage: number
  setSelectedImage: (index: number) => void
  isInProduct?: boolean
}) => {
  return (
    <div className={cn('relative pb-4', isInProduct ? 'p-10' : 'p-6')}>
      <div className='flex gap-8 rounded-md'>
        {images.length === 0 && (
          <ImageWithFallback
            src='/icons/diamond-ring.png'
            alt='slider image'
            width={isInProduct ? 400 : 400}
            height={isInProduct ? 400 : 400}
            className={`aspect-square shrink-0 rounded-md object-cover transition-transform duration-300 sm:w-full ${
              selectedImage === 0
                ? 'translate-x-0'
                : '-translate-x-[calc(100%+2rem)]'
            }`}
          />
        )}
        {images.map((image, index) => (
          <ImageWithFallback
            key={index}
            src={image.image}
            alt='slider image'
            width={isInProduct ? 400 : 400}
            height={isInProduct ? 400 : 400}
            className={`aspect-square shrink-0 rounded-md object-cover transition-transform duration-300 sm:w-full ${
              selectedImage === 0
                ? 'translate-x-0'
                : '-translate-x-[calc(100%+2rem)]'
            }`}
          />
        ))}
        {images.length > 1 && (
          <div className='show-on-device-with-hover opacity-0 transition-opacity group-hover:opacity-100'>
            <Button
              onClick={(e) => {
                e.preventDefault()
                e.stopPropagation()
                setSelectedImage(0)
              }}
              variant='ghost'
              className='absolute -left-2 top-1/2 h-16 -translate-y-1/2 hover:bg-transparent [&>div]:hover:bg-primary [&>div]:hover:text-background'
              disabled={selectedImage === 0}
            >
              <div className='rounded-full bg-background p-1 text-primary transition-colors'>
                <ChevronLeft />
              </div>
            </Button>
            <Button
              onClick={(e) => {
                e.preventDefault()
                e.stopPropagation()
                setSelectedImage(1)
              }}
              variant='ghost'
              className='absolute -right-2 top-1/2 h-16 -translate-y-1/2 hover:bg-transparent [&>div]:hover:bg-primary [&>div]:hover:text-background'
              disabled={selectedImage === 1}
            >
              <div className='rounded-full bg-background p-1 text-primary transition-colors'>
                <ChevronRight />
              </div>
            </Button>
          </div>
        )}
      </div>
    </div>
  )
}

export default ProductCardImages
